from typing import List, Protocol, Literal, Optional, Tuple, Union

from pydantic import BaseModel, Extra, ConfigDict

FILE_DATA_TYPE = "FILE"


class InferenceInput(BaseModel, extra=Extra.allow):
    name: str
    data: object
    datatype: Literal["FILE", "FP32", "FP64", "INT32", "str"]
    content_type: Optional[str] = None
    shape: Union[int, List[int]]


class InferenceOutputField(BaseModel):
    name: str
    datatype: Literal["FILE", "FP32", "FP64", "INT32", "dict", "str"]
    content_type: Optional[str] = None
    data: Optional[str] = None


class InferenceArgs(BaseModel):
    model_key: str
    parameters: Optional[List[Tuple[object, object]]] = None
    inputs: List[InferenceInput]
    output_fields: List[InferenceOutputField]
    model: Optional[object] = None

    model_config = ConfigDict(
        protected_namespaces=()
    )


class InferenceOutput(BaseModel):
    name: str
    data: object
    datatype: Literal["FILE", "INT32", "FP32", "FP64", "dict", "str"]
    content_type: Optional[str] = None
    shape: Union[int, List[int]]


class InferenceReturns(BaseModel):
    outputs: List[InferenceOutput]


class InferenceProtocol(Protocol):

    def run_inference(self, model_key: str, inputs: List[InferenceInput],
                      output_fields: List[InferenceOutputField], parameters: List[Tuple[object, object]] = None,
                      model: object = None) \
            -> List[InferenceOutput]:
        pass
