import logging
from typing import Optional

from pydantic import BaseModel

from unip.mlcmp.config import LICENSE_LOCAL_PATH


class License(BaseModel):
    content: Optional[str] = None
    location: Optional[str] = None


def get_license() -> License:
    logger = logging.getLogger(__name__)
    if LICENSE_LOCAL_PATH:
        try:
            with open(LICENSE_LOCAL_PATH) as f:
                text = f.read()
                location = '/modelversion/license'
                return License(content=text, location=location)
        except Exception as exc:
            logger.exception('Cannot read local license file', exc_info=exc)
            return License()
    logger.warning('License not specified')
    return License()

