import logging
from logging.config import dictConfig

from unip.mlcmp.request_id import request_id


class RequestIdFilter(logging.Filter):

    def __init__(self, default_value='-'):
        super().__init__()
        self.__default_value = default_value

    def filter(self, record):
        req_id = request_id.get(self.__default_value)
        record.request_id = req_id
        return True


def configure_logging():
    dictConfig({
        'version': 1,
        'filters': {
            'request_id': {
                '()': RequestIdFilter,
                'default_value': '-'
            },
        },
        'formatters': {
            'default': {
                'format': '[%(asctime)s] [%(levelname)s] [%(name)s]: %(message)s',
            },
            'default_req_ctx': {
                'format': '[%(asctime)s] [%(levelname)s] [%(name)s]: [%(request_id)s] %(message)s'
            }
        },
        'handlers': {
            'default': {
                'class': 'logging.StreamHandler',
                'stream': 'ext://sys.stdout',
                'formatter': 'default'
            },
            'default_req_ctx': {
                'class': 'logging.StreamHandler',
                'stream': 'ext://sys.stdout',
                'filters': ['request_id'],
                'formatter': 'default_req_ctx'
            }
        },
        'loggers': {
            'root': {
                'level': 'INFO',
                'handlers': ['default']
            },
            'unip.mlcmp': {
                'level': 'INFO',
                'handlers': ['default_req_ctx'],
                'propagate': False
            }
        }
    })